@@ -32,7 +32,6 @@
     indirect_structural_match,
     inline_no_sanitize,
     invalid_codeblock_attributes,
-    invalid_html_tags,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -40,15 +39,18 @@
     late_bound_lifetime_arguments,
     macro_expanded_macro_exports_accessed_by_absolute_paths,
     meta_variable_misuse,
+    missing_abi,
     missing_copy_implementations,
     missing_crate_level_docs,
     missing_docs,
+    missing_fragment_specifier,
     mixed_script_confusables,
     mutable_borrow_reservation_conflict,
     mutable_transmutes,
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
+    non_autolinks,
     non_camel_case_types,
     non_shorthand_field_patterns,
     non_snake_case,
@@ -56,12 +58,14 @@
     nontrivial_structural_match,
     order_dependent_trait_objects,
     overflowing_literals,
-    overlapping_patterns,
+    overlapping_range_endpoints,
+    panic_fmt,
     path_statements,
     patterns_in_fns_without_body,
     pointer_structural_match,
     private_doc_tests,
     private_in_public,
+    private_intra_doc_links,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
     redundant_semicolons,
@@ -87,6 +91,7 @@
     unsafe_code,
     unstable_features,
     unstable_name_collisions,
+    unsupported_naked_functions,
     unused_allocation,
     unused_assignments,
     unused_attributes,
@@ -107,6 +112,7 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
+    useless_deprecated,
     where_clauses_object_safety,
     while_true
 )]
@@ -115,6 +121,7 @@
     bare_trait_objects,
     box_pointers,
     elided_lifetimes_in_paths,
+    invalid_html_tags,
     missing_doc_code_examples,
     missing_debug_implementations,
     single_use_lifetimes,
